---
title: Racoon Album
thumbnail: racoon.jpg
---

# Your first album
This is a sample album. Do not forget the change the `title` and `thumbnail` in the meta section of `source/gallery/index.md`.
Add more pictures and text. Good luck and have fun!
